<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>En enkel, brukervennlig XMPP-klient</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Lisens:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Kildekode på GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Vis kildekoden på nett</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Innrapporter problemer</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">En enkel, brukervennlig Jabber/XMPP-klient</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Lisens:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Kildekode på GitHub</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Slett</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Kontosikkerhet</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="unfinished">Tillat tillegg av nye enheter ved bruk av QR-kode, men aldri vis passord som tekst. Denne handlingen kan ikke angres, så overvei å lagre passordet på annet vis først.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>Skru av visning av passordet</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>Ikke vis passordet i noen form. Denne handlingen kan ikke angres.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>Skru av visning av QR-kode og passord</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Overfør konto til en annen enhet</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Skann QR-koden eller skriv inn identitetsdetaljene som tekst på en annen enhet for å logge inn på den.

Merk:
Aldri vis denne QR-koden til noen andre. Den gir ubegrenset tilganger til kontoen din!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Sludreadresse:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Skjul QR-kode</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Vis som QR-kode</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Skjul tekst</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Vis som tekst</translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Tilbake</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Endre passord</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Nåværende passord:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nytt passord:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Nytt passord (gjenta:</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>De nye passordene samsvarer ikke.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Det nåværende passordet er ugyldig.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Du må være tilkoblet for å endre passordet ditt.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Etter å ha endret passordet ditt, vil du måtte skrive det inn igjen på dine andre enheter.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Endre</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished">Klarte ikke å endre passord: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Message copied to clipboard</source>
        <translation type="vanished">Melding kopiert til utklippstavle</translation>
    </message>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Kopier melding</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Rediger melding</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Avsløring</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Kopier melding</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Rediger melding</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Kopier nedlastings-nettadresse</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Siter melding</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Forfatt melding</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Send</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Bilde</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Lyd</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Dokument</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Annen fil</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Velg en fil</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Send en avsløringsmelding</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Avsløringshint</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Opphev forstumming av merknader</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Forstum merknader</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Vis profil</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Lukk</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Søk oppover</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Søk nedover</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Alle filer</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished">Avsløringshint</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation type="unfinished">Forfatt melding</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Kontoen din kunne ikke slettes fra tjeneren. Derfor ble den heller ikke fjernet fra dette programmet: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Veldig lavt</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lavt</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normalt</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Høyt</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Veldig høyt</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Konstant kvalitet</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Konstant bitrate</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Gjennomsnittlig bitrate</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Dobbelt-arbeidet</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">Endre</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Handling</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>Fjern passord fullstendig</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Passordet ditt vil ikke lenger være å finne i QR-koden.
Du vil ikke kunne logge inn via QR-koden uten å skrive passordet ditt igjen, fordi handlingen ikke kan angres.
Forsikre deg om at du har sikkerhetskopiert det hvis du ønsker å bruke kontoen din senere.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>Fjern passord</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>Ikke vis passordet som tekst</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Passordet ditt vil ikke lenger bli vist som tekst.
Du vil ikke kunne se passordet ditt som tekst igjen fordi handlingen ikke kan angres.
Forsikre deg om at du har sikkerhetskopiert passordet hvis du ønsker å bruke den senere.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>Ikke vis passord</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Kunne ikke lagre fil: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Nedlasting mislyktes: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Favoritter</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Folk</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natur</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Mat</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Aktivitet</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Reise</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Objekter</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Symboler</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Flagg</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Søk</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Søk etter emoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Velg en sludring for å begynne å sende meldinger</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Velg en fil</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>go to parent folder</source>
        <translation type="vanished">gå til overnevnt mappe</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Lukk</translation>
    </message>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Gå til ovennevnt mappe</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Framover</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Back</source>
        <translation type="vanished">Tilbake</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Logg ut</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Inviter venner</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Invitasjonslenke kopiert til utklippstavle</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Frakoblet</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Pålogget</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">Kobler til…</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Bytt enhet</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Kunne ikke sende melding, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="vanished">Kunne ikke legge til kontakt, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="vanished">Kunne ikke fjerne kontakt, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Lenken vil åpnes etter at du har koblet til.</translation>
    </message>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="vanished">Kunne ikke sende fil, som resultat av å ikke være tilkoblet.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Fant ingen gyldig QR-kode for innlogging.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Fjern konto fra dette programmet</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>Kontoen din vil bli fjernet fra dette programmet.
Passordet ditt vil bli slettet, forsikre deg om at det er lagret i en passordshåndterer, eller at du husker det!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Logg inn</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Logg inn på din XMPP-konto</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Din Jabber-ID:</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Din diaspora*-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">bruker@eksempel.no</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">bruker@diaspora.pod</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Ditt passord:</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Prøv igjen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Koble til</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Kobler til…</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Ugyldig brukernavn eller passord.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Kan ikke koble til tjeneren. Sjekk din internettilknytning.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Tjeneren støtter ikke sikre tilkoblinger.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Feil under forsøk på sikker tilkobling.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Kunne ikke fortolke tjenerens adresse. Sjekk din JID igjen.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Kunne ikke koble til tjeneren.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Identitetsbekreftelsesprotokollen støttes ikke av tjeneren.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">En ukjent feil inntraff; sjekk loggen for detaljer.</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Forvalg</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Ta bilde</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Ta opp video</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Ta opp stemme</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Send plassering</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Velg fil</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Velg bilde</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Velg video</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Velg lydfil</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Velg dokument</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Lyd</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished">Dokument</translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Bilde</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished">Fil</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished">Avsløring</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="obsolete">Kunne ikke sende melding, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="obsolete">Kunne ikke korrigere melding, siden du ikke er tilkoblet.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Avsløring</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Meldingen kunne ikke sendes.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation type="unfinished">Meldingstilkobling mislyktes.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Venter</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Sendt</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Levert</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Feil</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Multimediainnstillinger</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Sett opp</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Bildeknipsing</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Lydopptak</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Videoopptak</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Lydinngang</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Beholder</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Bilde</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Lyd</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Oppløsning</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Samplingstakt</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Rammetakt</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Igangsetter…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Utilgjengelig</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Tar opp…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauset</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Image</source>
        <translation type="obsolete">Bilde</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Lyd</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="obsolete">Video</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Klar</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Igangsetter…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Utilgjengelig</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Tar opp… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>Satt på pause %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Fjern passord</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished">Du kan bestemme deg for å ikke vise passordet for &lt;b&gt;%1&lt;/b&gt; som tekst i fremtiden, eller å fjerne det helt fra konto-overføringen. Hvis du fjerner passordet helt, vil du ikke kunne bruke konto-overføring via skanning uten å skrive inn passordet ditt, fordi det også fjernes fra QR-koden.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Ikke vis passordet som tekst</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Fjern fullstendig</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Marker som lest</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished">Tilgjengelig</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished">Ledig for sludring</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished">Borte</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished">Ikke forstyrr</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished">Lengre tids fravær</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Frakoblet</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="obsolete">Tilgjengelig</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="obsolete">Ledig for sludring</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="obsolete">Borte</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="obsolete">Ikke forstyrr</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="obsolete">Lengre tids fravær</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="obsolete">Frakoblet</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Feil</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished">Ugyldig brukernavn eller passord.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished">Kan ikke koble til tjeneren. Sjekk din internettilknytning.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished">Tjeneren støtter ikke sikre tilkoblinger.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished">Feil under forsøk på sikker tilkobling.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="vanished">Kunne ikke fortolke tjenerens adresse. Sjekk ditt tjenernavn.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Kunne ikke koble til tjeneren.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished">Identitetsbekreftelsesprotokollen støttes ikke av tjeneren.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Denne tjeneren støtter ikke registrering.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>Tjeneren er nede eller blokkert av en brannmur.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>Tilkoblingen kunne ikke gjenoppfriskes.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished">Innvilg internettilgang i systemets tilgangsoppsett.</translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Kunne ikke generere QR-kode: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished">Skann QR-kode</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished">Vis forklaring</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished">Fortsett uten QR-kode</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished">Skann QR-koden fra din eksisterende enhet for å overføre kontoen din.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">Kobler til…</translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished">Kameraformatet &quot;%1&quot; støttes ikke.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished">Kamera ikke tilgjengelig.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished">Kamera ditt er opptatt.
Prøv å lukke andre programmer ved bruk av kameraet.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">Skann QR-kode</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Kamera ikke tilgjengelig.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Kamera ditt er opptatt.
Prøv å lukke andre programmer ved bruk av kameraet.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">Kameraformatet &quot;%1&quot; støttes ikke.</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="vanished">Skann QR-koden fra din eksisterende enhet for å overføre kontoen din.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="vanished">Vis forklaring</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">Skann</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">Fortsett uten QR-kode</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="obsolete">Kobler til…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Sett opp</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Registrer ny konto</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Bruk eksisterende konto</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Passord endret</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Klarte ikke å endre passord: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Slett konto fullstendig</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Kontoen din vil slettes fullstendig, fra programmet og tjeneren.
Du vil ikke kunne bruke kontoen igjen.</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Slett</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Legg til ny kontakt</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Kallenavn:</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>bruker@eksempel.no</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Dette vil også sende en forespørsel om tilgang til kontaktens tilstedeværelsesinfo.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Valgfri melding:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Fortell din sludrepartner hvem du er.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Feil: Sjekk JID-en.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Tilgjengelig</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Ledig for sludring</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Borte</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Ikke forstyrr</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Lengre tids fravær</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Frakoblet</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Feil</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation type="vanished">Ugyldig</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="unfinished">Kunne ikke legge til kontakt, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="unfinished">Kunne ikke fjerne kontakt, som følge av manglende tilkobling.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Avsløring</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Kunne ikke gi kontakten nytt navn, fordi den ikke er tilkoblet.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Kontakter</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Legg til ny kontakt</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Kobler til…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Frakoblet</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Søk i kontakter</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">Ønsker du virkelig å slette kontakten &quot;%1&quot; fra din kontaktliste?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Slett kontakt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;%1&gt; from your roster?</source>
        <translation type="vanished">Ønsker du virkelig å slette kontakten &lt;%1&gt; fra din kontaktliste?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Ønsker du virkelig å slette kontakten &lt;b&gt;%1&lt;/b&gt; from din kontaktliste?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Gi kontakten nytt navn</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Gi nytt navn</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Send</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Bildetekst</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Egendefinert tjener</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Ingen begrensning</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 dager</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished">Endre passord</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished">Endrer passord på kontoen din. Du vil måtte skrive det inn igjen på dine andre enheter.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Multimedia-innstillinger</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Sett opp bilde- video- og lyd-opptaksinnstillinger</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Innstillinger</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Kontosikkerhet</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="vanished">Sett opp hvorvidt denne enheten kan brukes for å logge inn på en annen</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Fjern konto fra Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Fjern konto fra dette programmet</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Slett konto</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Slett konto fra tjeneren</translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Endre passord</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Endrer passord på kontoen din. Du vil måtte skrive det inn igjen på dine andre enheter.</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Innstillinger</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Nyt fri kommunikasjon på alle enheter.</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>La oss begynne</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Abonnementsforespørsel</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Du har mottatt en abonnementsforespørsel av &lt;b&gt;%1&lt;/b&gt;. Hvis du godtar den, vil kontoen ha tilgang til din tilstedeværelsesstatus.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Avslå</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Godta</translation>
    </message>
</context>
<context>
    <name>ToolBarApplicationHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Flere handlinger</translation>
    </message>
</context>
<context>
    <name>ToolBarPageHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="obsolete">Flere handlinger</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="unfinished">Kunne ikke sende fil, som resultat av å ikke være tilkoblet.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Fil</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">Meldingen kunne ikke sendes.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished">Gi kontakten nytt navn</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Kallenavn</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">Om</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Geburtsdag</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Nettside</translation>
    </message>
</context>
</TS>
